# Metrics Operator Python

> Helpers for submitting CRD with Python and parsing logs.

![https://raw.githubusercontent.com/converged-computing/metrics-operator/main/docs/images/metrics-operator-banner.png](https://raw.githubusercontent.com/converged-computing/metrics-operator/main/docs/images/metrics-operator-banner.png)

Welcome to the Metrics Operator Python! You can learn more about the operator
at the  ⭐️ [Documentation](https://converged-computing.github.io/metrics-operator/) ⭐️
and see our [python examples](https://github.com/converged-computing/metrics-operator/tree/main/examples/python/) for examples of using this module.

## License

HPCIC DevTools is distributed under the terms of the MIT license.
All new contributions must be made under this license.

See [LICENSE](https://github.com/converged-computing/cloud-select/blob/main/LICENSE),
[COPYRIGHT](https://github.com/converged-computing/cloud-select/blob/main/COPYRIGHT), and
[NOTICE](https://github.com/converged-computing/cloud-select/blob/main/NOTICE) for details.

SPDX-License-Identifier: (MIT)

LLNL-CODE- 842614
